==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/compat/jei/category/FanSmokingCategory.java <==
package com.zurrtum.create.client.compat.jei.category;

import com.zurrtum.create.AllItems;
import com.zurrtum.create.AllRecipeTypes;
import com.zurrtum.create.client.compat.jei.CreateCategory;
import com.zurrtum.create.client.compat.jei.JeiClientPlugin;
import com.zurrtum.create.client.compat.jei.renderer.TwoIconRenderer;
import com.zurrtum.create.client.foundation.gui.AllGuiTextures;
import com.zurrtum.create.client.foundation.gui.render.FanRenderState;
import com.zurrtum.create.client.foundation.utility.CreateLang;
import mezz.jei.api.gui.builder.IRecipeLayoutBuilder;
import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.ingredient.IRecipeSlotsView;
import mezz.jei.api.recipe.IFocusGroup;
import mezz.jei.api.recipe.types.IRecipeType;
import net.minecraft.class_10289;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_3862;
import net.minecraft.class_3956;
import net.minecraft.class_8786;
import org.jetbrains.annotations.NotNull;
import org.joml.Matrix3x2f;

import java.util.List;

public class FanSmokingCategory extends CreateCategory<class_8786<class_3862>> {
    public static List<class_8786<class_3862>> getRecipes(class_10289 preparedRecipes) {
        return preparedRecipes.method_64698(class_3956.field_17548).stream().filter(AllRecipeTypes.CAN_BE_AUTOMATED).toList();
    }

    @Override
    @NotNull
    public IRecipeType<class_8786<class_3862>> getRecipeType() {
        return JeiClientPlugin.FAN_SMOKING;
    }

    @Override
    @NotNull
    public class_2561 getTitle() {
        return CreateLang.translateDirect("recipe.fan_smoking");
    }

    @Override
    public IDrawable getIcon() {
        return new TwoIconRenderer(AllItems.PROPELLER, class_1802.field_17346);
    }

    @Override
    public int getHeight() {
        return 77;
    }

    @Override
    public void setRecipe(IRecipeLayoutBuilder builder, class_8786<class_3862> entry, IFocusGroup focuses) {
        class_3862 recipe = entry.comp_1933();
        builder.addInputSlot(21, 48).setBackground(SLOT, -1, -1).add(recipe.method_64720());
        builder.addOutputSlot(141, 48).setBackground(SLOT, -1, -1).add(recipe.method_64721());
    }

    @Override
    public void draw(class_8786<class_3862> entry, IRecipeSlotsView recipeSlotsView, class_332 graphics, double mouseX, double mouseY) {
        AllGuiTextures.JEI_SHADOW.render(graphics, 46, 27);
        AllGuiTextures.JEI_LIGHT.render(graphics, 65, 39);
        AllGuiTextures.JEI_LONG_ARROW.render(graphics, 54, 51);
        graphics.field_59826.method_70922(new FanRenderState(new Matrix3x2f(graphics.method_51448()), 56, 4, class_2246.field_10036.method_9564()));
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/compat/jei/category/FanSmokingCategory.java <==
package com.zurrtum.create.client.compat.jei.category;

import com.zurrtum.create.AllItems;
import com.zurrtum.create.AllRecipeTypes;
import com.zurrtum.create.client.compat.jei.CreateCategory;
import com.zurrtum.create.client.compat.jei.JeiClientPlugin;
import com.zurrtum.create.client.compat.jei.renderer.TwoIconRenderer;
import com.zurrtum.create.client.foundation.gui.AllGuiTextures;
import com.zurrtum.create.client.foundation.gui.render.FanRenderState;
import com.zurrtum.create.client.foundation.utility.CreateLang;
import mezz.jei.api.gui.builder.IRecipeLayoutBuilder;
import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.ingredient.IRecipeSlotsView;
import mezz.jei.api.recipe.IFocusGroup;
import mezz.jei.api.recipe.types.IRecipeType;
import net.minecraft.class_10289;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_3862;
import net.minecraft.class_3956;
import net.minecraft.class_8786;
import org.jetbrains.annotations.NotNull;
import org.joml.Matrix3x2f;

import java.util.List;

public class FanSmokingCategory extends CreateCategory<class_8786<class_3862>> {
    public static List<class_8786<class_3862>> getRecipes(class_10289 preparedRecipes) {
        return preparedRecipes.method_64698(class_3956.field_17548).stream().filter(AllRecipeTypes.CAN_BE_AUTOMATED).toList();
    }

    @Override
    @NotNull
    public IRecipeType<class_8786<class_3862>> getRecipeType() {
        return JeiClientPlugin.FAN_SMOKING;
    }

    @Override
    @NotNull
    public class_2561 getTitle() {
        return CreateLang.translateDirect("recipe.fan_smoking");
    }

    @Override
    public IDrawable getIcon() {
        return new TwoIconRenderer(AllItems.PROPELLER, class_1802.field_17346);
    }

    @Override
    public int getHeight() {
        return 77;
    }

    @Override
    public void setRecipe(IRecipeLayoutBuilder builder, class_8786<class_3862> entry, IFocusGroup focuses) {
        class_3862 recipe = entry.comp_1933();
        builder.addInputSlot(21, 48).setBackground(SLOT, -1, -1).add(recipe.method_64720());
        builder.addOutputSlot(141, 48).setBackground(SLOT, -1, -1).add(recipe.method_64721());
    }

    @Override
    public void draw(class_8786<class_3862> entry, IRecipeSlotsView recipeSlotsView, class_332 graphics, double mouseX, double mouseY) {
        AllGuiTextures.JEI_SHADOW.render(graphics, 46, 27);
        AllGuiTextures.JEI_LIGHT.render(graphics, 65, 39);
        AllGuiTextures.JEI_LONG_ARROW.render(graphics, 54, 51);
        graphics.field_59826.method_70922(new FanRenderState(
            new Matrix3x2f(graphics.method_51448()),
            56,
            4,
            class_2246.field_10036.method_9564()
        ));
    }
}
